/*
 * Copyright (C) 2025 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#pragma once

#include "igfxfmid.h"

namespace NEO {
constexpr GFXCORE_FAMILY maxCoreEnumValue = IGFX_MAX_CORE;
constexpr PRODUCT_FAMILY maxProductEnumValue = IGFX_MAX_PRODUCT;
} // namespace NEO
